package com.jms.queue.async.mdb;
/**
 * The MDBTextListener class implements the MessageListener 
 * interface by defining an onMessage method that displays 
 * the contents of a TextMessage.
 *
 * This class acts as the message driven bean listener.
 */
import javax.ejb.ActivationConfigProperty;
import javax.ejb.MessageDriven;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

import org.jboss.ejb3.annotation.ResourceAdapter;

@MessageDriven(activationConfig = {
		@ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Queue"),
		@ActivationConfigProperty(propertyName = "destination", propertyValue = "queue/requestQ"),
		@ActivationConfigProperty(propertyName = "hA", propertyValue = "true"),
		@ActivationConfigProperty(propertyName = "acknowledgeMode", propertyValue = "auto-acknowledge"), 
		@ActivationConfigProperty(propertyName = "maxSession", propertyValue = MDBTextListener.poolSize)})
@ResourceAdapter("hornetq-ra.rar")

@TransactionManagement(value = TransactionManagementType.CONTAINER)
@TransactionAttribute(value = TransactionAttributeType.REQUIRED)
public class MDBTextListener implements MessageListener {
	private static final String poolSize = "5";
    /**
     * Casts the message to a TextMessage and displays its text.
     *
     * @param message     the incoming message
     */
    public void onMessage(Message message) {
        TextMessage msg = null;
            
        try {
            if (message instanceof TextMessage) {
                msg = (TextMessage) message;
                System.out.println("MDB Text Listener reading message: " +
                    msg.getText());
            } else {
                System.out.println("Message of wrong type: " +
                    message.getClass().getName());
            }
        } catch (JMSException e) {
            System.out.println("JMSException in onMessage(): " +
                e.toString());
        } catch (Throwable t) {
            System.out.println("Exception in onMessage():" +
                t.getMessage());
        }
    }
}
